package com.mobcodes.microsoft_appcenter_flutter;

import android.app.Activity;
import android.app.Application;

import androidx.annotation.NonNull;

import com.microsoft.appcenter.AppCenter;
import com.microsoft.appcenter.analytics.Analytics;
import com.microsoft.appcenter.crashes.Crashes;
import com.microsoft.appcenter.utils.async.AppCenterConsumer;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.UUID;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** MicrosoftAppcenterFlutterPlugin */
public class MicrosoftAppcenterFlutterPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private Application application;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "microsoft_appcenter_flutter");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {

    switch (call.method) {
      case "installId":
        //result.success(AppCenter.getInstallId().get().toString());
        result.success("skamskam");
        break;
      case "isEnabled":
        result.success(AppCenter.isEnabled().get());
        break;
      case "setEnabled":
        Boolean isEnabled = call.argument("isEnabled");
        AppCenter.setEnabled(isEnabled).get();
        result.success(null);
        break;
      case "configure":
        String secret = call.argument("appSecret").toString();;
        AppCenter.configure(application, secret);
        result.success(null);
        break;
      case "start":
        String appSecret = call.argument("appSecret").toString();;

        AppCenter.start(application, appSecret, Analytics.class);
        result.success(null);
        break;

        // Analytics
      case "isEnabledAnalytics":
        result.success(Analytics.isEnabled().get().booleanValue());
        break;
      case "setEnabledAnalytics":
        Boolean isEnabledAnalytics = call.argument("isEnabled");
        Analytics.setEnabled(isEnabledAnalytics).get();
        result.success(null);
        break;
      case "trackEvent":
        String name = call.argument("name");
        Map<String, String> properties = call.argument("properties");
        Analytics.trackEvent(name, properties);
        break;

        /// Crashes
      case "isEnabledCrashes":
        result.success(true);
        //result.success(Crashes.isEnabled().get());
        break;
      case "setEnabledCrashes":
        Boolean isEnabledCrashes = call.argument("isEnabled");
        Crashes.setEnabled(isEnabledCrashes).get();
        result.success(null);
        break;
      case "generateTestCrash":
        Crashes.generateTestCrash();
        result.success(0);
        break;

      default:
        result.notImplemented();
        break;
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  @Override
  public void onAttachedToActivity(@NonNull ActivityPluginBinding binding) {
    application = binding.getActivity().getApplication();
  }

  @Override
  public void onDetachedFromActivityForConfigChanges() {

  }

  @Override
  public void onReattachedToActivityForConfigChanges(@NonNull ActivityPluginBinding binding) {

  }

  @Override
  public void onDetachedFromActivity() {

  }
}
